.. _generate_cf_finite_optimized:

`generate_cf_finite_optimized`
==============================

.. automodule:: oasis_stat
   :members: generate_cf_finite_optimized
   :undoc-members:
   :show-inheritance:
   :noindex:
   
Description
-----------
Generates optimized column and row embeddings for the finite sample p-value. Tries multiple random initializations and returns the embeddings that maximize the finite sample p-value on the given X.